@@ -1,4 +1,4 @@
-package urpm::md5sum; # $Id: md5sum.pm 265136 2010-01-22 12:10:01Z misc $
+package urpm::md5sum;
 
 use strict;
 use urpm::util qw(cat_ file_size);
@@ -100,7 +100,6 @@ sub compute {
 
 1;
 
-__END__
 
 =back
 
@@ -110,4 +109,6 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =cut
