@@ -1,6 +1,5 @@
 package urpm::msg;
 
-# $Id: msg.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 use strict;
 no warnings;
@@ -166,8 +165,8 @@ sub _format_line_selected_packages {
 
     my @l = map {
 	my @name_and_evr = $_->fullname;
-	if ($state->{selected}{$_->id}{suggested}) {
-	    push @name_and_evr, N("(suggested)");
+	if ($state->{selected}{$_->id}{recommended}) {
+	    push @name_and_evr, N("(recommended)");
 	}
 	\@name_and_evr;
     } sort { $a->name cmp $b->name } @$pkgs;
@@ -212,7 +211,6 @@ sub localtime2changelog { scalar(localtime($_[0])) =~ /(.*) \S+ (\d{4})$/ && "$1
 
 1;
 
-__END__
 
 =head1 NAME
 
@@ -228,4 +226,6 @@ Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =cut
